@@ -11,6 +11,6 @@ class MissingDependency extends \RuntimeException implements Exception
      */
     public static function create(string $package, string $name)
     {
-        return new self(sprintf('In order to use "%s" you need to install "%s". Run "composer require %s" and all your problems are solved.', $name, $package, $package));
+        return new self(\sprintf('In order to use "%s" you need to install "%s". Run "composer require %s" and all your problems are solved.', $name, $package, $package));
     }
 }
