@@ -54,7 +54,7 @@ class ResponseBodyStream implements ResultStream
             return;
         }
         if ($this->partialRead) {
-            throw new LogicException(sprintf('You can not call "%s". Another process doesn\'t reading "getChunks" till the end.', __METHOD__));
+            throw new LogicException(\sprintf('You can not call "%s". Another process doesn\'t reading "getChunks" till the end.', __METHOD__));
         }
 
         $resource = fopen('php://temp', 'rb+');
