@@ -7,19 +7,33 @@ use AsyncAws\Core\Exception\InvalidArgument;
 /**
  * You can pass custom key-value pair attributes when you assume a role or federate a user. These are called session
  * tags. You can then use the session tags to control access to resources. For more information, see Tagging Amazon Web
- * Services STS Sessions in the *IAM User Guide*.
+ * Services STS Sessions [^1] in the *IAM User Guide*.
  *
- * @see https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html
+ * [^1]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html
  */
 final class Tag
 {
     /**
      * The key for a session tag.
+     *
+     * You can pass up to 50 session tags. The plain text session tag keys can’t exceed 128 characters. For these and
+     * additional limits, see IAM and STS Character Limits [^1] in the *IAM User Guide*.
+     *
+     * [^1]: https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length
+     *
+     * @var string
      */
     private $key;
 
     /**
      * The value for a session tag.
+     *
+     * You can pass up to 50 session tags. The plain text session tag values can’t exceed 256 characters. For these and
+     * additional limits, see IAM and STS Character Limits [^1] in the *IAM User Guide*.
+     *
+     * [^1]: https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length
+     *
+     * @var string
      */
     private $value;
 
@@ -31,10 +45,16 @@ final class Tag
      */
     public function __construct(array $input)
     {
-        $this->key = $input['Key'] ?? null;
-        $this->value = $input['Value'] ?? null;
+        $this->key = $input['Key'] ?? $this->throwException(new InvalidArgument('Missing required field "Key".'));
+        $this->value = $input['Value'] ?? $this->throwException(new InvalidArgument('Missing required field "Value".'));
     }
 
+    /**
+     * @param array{
+     *   Key: string,
+     *   Value: string,
+     * }|Tag $input
+     */
     public static function create($input): self
     {
         return $input instanceof self ? $input : new self($input);
@@ -56,15 +76,19 @@ final class Tag
     public function requestBody(): array
     {
         $payload = [];
-        if (null === $v = $this->key) {
-            throw new InvalidArgument(sprintf('Missing parameter "Key" for "%s". The value cannot be null.', __CLASS__));
-        }
+        $v = $this->key;
         $payload['Key'] = $v;
-        if (null === $v = $this->value) {
-            throw new InvalidArgument(sprintf('Missing parameter "Value" for "%s". The value cannot be null.', __CLASS__));
-        }
+        $v = $this->value;
         $payload['Value'] = $v;
 
         return $payload;
     }
+
+    /**
+     * @return never
+     */
+    private function throwException(\Throwable $exception)
+    {
+        throw $exception;
+    }
 }
